@@ -6,12 +6,12 @@ import (
 
 	"github.com/google/go-cmp/cmp"
 	"github.com/helmfile/vals"
+	"github.com/stretchr/testify/assert"
 	"go.uber.org/zap"
 
 	"github.com/helmfile/helmfile/pkg/exectest"
 	ffs "github.com/helmfile/helmfile/pkg/filesystem"
 	"github.com/helmfile/helmfile/pkg/helmexec"
-	"github.com/helmfile/helmfile/pkg/testhelper"
 )
 
 func TestSync(t *testing.T) {
@@ -132,10 +132,7 @@ func TestSync(t *testing.T) {
 		if tc.log != "" {
 			actual := bs.String()
 
-			diff, exists := testhelper.Diff(tc.log, actual, 3)
-			if exists {
-				t.Errorf("unexpected log:\nDIFF\n%s\nEOD", diff)
-			}
+			assert.Equal(t, tc.log, actual)
 		}
 	}
 
