@@ -5,26 +5,28 @@ import (
 	"testing"
 
 	"github.com/helmfile/vals"
+	"github.com/stretchr/testify/assert"
 	"go.uber.org/zap"
 
 	"github.com/helmfile/helmfile/pkg/exectest"
 	ffs "github.com/helmfile/helmfile/pkg/filesystem"
 	"github.com/helmfile/helmfile/pkg/helmexec"
-	"github.com/helmfile/helmfile/pkg/testhelper"
 )
 
 func TestDestroy_2(t *testing.T) {
 	type testcase struct {
-		ns          string
-		concurrency int
-		error       string
-		files       map[string]string
-		selectors   []string
-		lists       map[exectest.ListKey]string
-		diffs       map[exectest.DiffKey]error
-		upgraded    []exectest.Release
-		deleted     []exectest.Release
-		log         string
+		ns            string
+		concurrency   int
+		error         string
+		files         map[string]string
+		selectors     []string
+		lists         map[exectest.ListKey]string
+		diffs         map[exectest.DiffKey]error
+		upgraded      []exectest.Release
+		deleted       []exectest.Release
+		log           string
+		deleteWait    bool
+		deleteTimeout int
 	}
 
 	check := func(t *testing.T, tc testcase) {
@@ -77,6 +79,8 @@ func TestDestroy_2(t *testing.T) {
 				concurrency:            tc.concurrency,
 				logger:                 logger,
 				includeTransitiveNeeds: false,
+				deleteWait:             tc.deleteWait,
+				deleteTimeout:          tc.deleteTimeout,
 			})
 
 			switch {
@@ -122,10 +126,7 @@ func TestDestroy_2(t *testing.T) {
 		if tc.log != "" {
 			actual := bs.String()
 
-			diff, exists := testhelper.Diff(tc.log, actual, 3)
-			if exists {
-				t.Errorf("unexpected log:\nDIFF\n%s\nEOD", diff)
-			}
+			assert.Equal(t, tc.log, actual)
 		}
 	}
 
@@ -455,6 +456,9 @@ database 	4       	Fri Nov  1 08:40:07 2019	DEPLOYED	mysql-3.1.0	3.1.0      	def
 anotherbackend 	4       	Fri Nov  1 08:40:07 2019	DEPLOYED	anotherbackend-3.1.0	3.1.0      	default
 `,
 			},
+			// Enable wait and set timeout for destroy
+			deleteWait:    true,
+			deleteTimeout: 300,
 			// Disable concurrency to avoid in-deterministic result
 			concurrency: 1,
 			upgraded:    []exectest.Release{},
