@@ -6,12 +6,12 @@ import (
 	"testing"
 
 	"github.com/helmfile/vals"
+	"github.com/stretchr/testify/assert"
 	"go.uber.org/zap"
 
 	"github.com/helmfile/helmfile/pkg/exectest"
 	ffs "github.com/helmfile/helmfile/pkg/filesystem"
 	"github.com/helmfile/helmfile/pkg/helmexec"
-	"github.com/helmfile/helmfile/pkg/testhelper"
 )
 
 const (
@@ -41,6 +41,8 @@ type destroyConfig struct {
 	logger                 *zap.SugaredLogger
 	includeTransitiveNeeds bool
 	skipCharts             bool
+	deleteWait             bool
+	deleteTimeout          int
 }
 
 func (d destroyConfig) Args() string {
@@ -75,18 +77,28 @@ func (d destroyConfig) IncludeTransitiveNeeds() bool {
 	return d.includeTransitiveNeeds
 }
 
+func (d destroyConfig) DeleteWait() bool {
+	return d.deleteWait
+}
+
+func (d destroyConfig) DeleteTimeout() int {
+	return d.deleteTimeout
+}
+
 func TestDestroy(t *testing.T) {
 	type testcase struct {
-		ns          string
-		concurrency int
-		error       string
-		files       map[string]string
-		selectors   []string
-		lists       map[exectest.ListKey]string
-		diffs       map[exectest.DiffKey]error
-		upgraded    []exectest.Release
-		deleted     []exectest.Release
-		log         string
+		ns            string
+		concurrency   int
+		error         string
+		files         map[string]string
+		selectors     []string
+		lists         map[exectest.ListKey]string
+		diffs         map[exectest.DiffKey]error
+		upgraded      []exectest.Release
+		deleted       []exectest.Release
+		log           string
+		deleteWait    bool
+		deleteTimeout int
 	}
 
 	check := func(t *testing.T, tc testcase) {
@@ -183,10 +195,7 @@ func TestDestroy(t *testing.T) {
 		if tc.log != "" {
 			actual := bs.String()
 
-			diff, exists := testhelper.Diff(tc.log, actual, 3)
-			if exists {
-				t.Errorf("unexpected log:\nDIFF\n%s\nEOD", diff)
-			}
+			assert.Equal(t, tc.log, actual)
 		}
 	}
 
@@ -300,7 +309,10 @@ anotherbackend 	4       	Fri Nov  1 08:40:07 2019	DEPLOYED	anotherbackend-3.1.0
 			},
 			// Disable concurrency to avoid in-deterministic result
 			concurrency: 1,
-			upgraded:    []exectest.Release{},
+			// Enable wait and set timeout for destroy
+			deleteWait:    true,
+			deleteTimeout: 300,
+			upgraded:      []exectest.Release{},
 			deleted: []exectest.Release{
 				{Name: "frontend-v3", Flags: []string{}},
 				{Name: "frontend-v2", Flags: []string{}},
@@ -748,7 +760,10 @@ changing working directory back to "/path/to"
 			},
 			// Disable concurrency to avoid in-deterministic result
 			concurrency: 1,
-			upgraded:    []exectest.Release{},
+			// Enable wait and set timeout for destroy
+			deleteWait:    true,
+			deleteTimeout: 300,
+			upgraded:      []exectest.Release{},
 			deleted: []exectest.Release{
 				{Name: "frontend-v1", Flags: []string{}},
 			},
